
# Slot: affects degradation of


holds between two molecular entities where the action or effect of one impacts the rate of degradation of the other within a system of interest, where chemical degradation is defined act or process of simplifying or breaking down a molecule into smaller parts, either naturally or artificially (Oxford English Dictionary, UK, 1995)

URI: [biolink:affects_degradation_of](https://w3id.org/biolink/vocab/affects_degradation_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [decreases degradation of](decreases_degradation_of.md)
 *  [increases degradation of](increases_degradation_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:affects_degradation_of |
| **Narrow Mappings:** | | CTD:affects_cleavage |
|  | | CTD:affects_hydrolysis |

